@@ -20,8 +20,8 @@ summary.Rcpp_RMLNetwork <- function(object, ...) {
             mlnet.table[i,1] = vcount(mlnet.layers[[i]])
             mlnet.table[i,2] = ecount(mlnet.layers[[i]])
             mlnet.table[i,3] = is.directed(mlnet.layers[[i]])
-            mlnet.table[i,4] = count_components(mlnet.layers[[i]])
-            mlnet.table[i,5] = max(components(mlnet.layers[[i]])$csize)
+            mlnet.table[i,4] = count_components(mlnet.layers[[i]], mode = "strong")
+            mlnet.table[i,5] = max(components(mlnet.layers[[i]], mode = "strong")$csize)
             mlnet.table[i,6] = graph.density(mlnet.layers[[i]])
             mlnet.table[i,7] = transitivity(mlnet.layers[[i]])
             mlnet.table[i,8] = average.path.length(mlnet.layers[[i]])
