@@ -47,9 +47,19 @@ convert(
         meta->add(v);
     }
 
+    bool weighted = is_weighted(g);
+    
     for (auto e: *g->edges())
     {
-        meta->edge(e->v1, e->v2);
+        if (weighted)
+        {
+            double w = get_weight(g, e);
+            meta->edge(e->v1, e->v2, w);
+        }
+        else 
+        {
+            meta->edge(e->v1, e->v2);
+        }
     }
 
     return meta;
@@ -150,7 +160,8 @@ std::unique_ptr<CommunityStructure<Network>>
 
 std::unique_ptr<MetaNetwork>
 pass(
-    const Network* g
+    const Network* g,
+    double gamma
 )
 {
     //std::cout << "PASS" << std::endl;
@@ -222,7 +233,7 @@ pass(
 
                     double A_ij = e ? get_weight(g, e) : 0;
 
-                    double contribution = A_ij - w_degree.at(v)*w_degree.at(n)/m/2;
+                    double contribution = A_ij - gamma*w_degree.at(v)*w_degree.at(n)/m/2;
 
                     improvement[c] += contribution;
                 }
@@ -242,7 +253,7 @@ pass(
 
                 double A_ij = e ? get_weight(g, e) : 0;
 
-                double contribution = A_ij - w_degree.at(v)*w_degree.at(n)/m/2;
+                double contribution = A_ij - gamma*w_degree.at(v)*w_degree.at(n)/m/2;
 
                 loss += contribution;
             }
